@@ -8,5 +8,8 @@ router.register('probes', views.ProbeViewSet)
 router.register('contractors', views.ContractorViewSet)
 router.register('contracts', views.ContractViewSet)
 router.register('invoices', views.InvoiceViewSet)
+router.register('components', views.ComponentViewSet)
+router.register('component-services', views.ComponentServiceViewSet)
+
 
 urlpatterns = router.urls
